Getting started
===============

.. contents::
   :local:


Example inventory
-----------------

The ``debops.auth`` role is included in the :file:`common.yml` DebOps playbook
and doesn't need to be specifically activated.


Example playbook
----------------

If you are using this role without DebOps, here's an example Ansible playbook
that uses the ``debops.auth`` role:

.. literalinclude:: ../../../../ansible/playbooks/service/auth.yml
   :language: yaml
